@@ -39,6 +39,3 @@ class mock_api:
             print('PORT {}: {}'.format(port,msg))
         else :
             print('PORT {}: \nattributes: {}\nbody: {}'.format(port,str(msg.attributes),str(msg.body)))
-
-    def add_generator(self,func):
-        func()
